import { Nullable } from '@mlytics/core-ts/core/type/basic';
import { Timer } from '@mlytics/core-ts/core/util/watch';
import { Resource } from '../../../../kernel/core/model/service/resource';
declare class HLSProxy {
    static clear(uri: string): Promise<void>;
}
declare class HLSLoaderProxy {
    protected _resource: Resource;
    protected _controller: HLSController;
    fetch(uri: string): Promise<Resource>;
    protected _setupResource(uri: string): Promise<void>;
    protected _setupController(): Promise<void>;
    protected _fetchController(): Promise<void>;
    protected _buildController(): Promise<void>;
    protected _fetchResource(): Promise<void>;
    abort(): Promise<void>;
    protected _abortResource(): Promise<void>;
}
declare class HLSController {
    protected readonly _options: HLSControllerOptions;
    protected _info: HLSControllerInfo;
    constructor(_options: HLSControllerOptions);
    get info(): HLSControllerInfo;
    protected _initialize(): void;
    fetch(resource: Resource): Promise<void>;
    protected _injectInfo(resource: Resource): Promise<void>;
    protected _shouldBufferPlay(resource: Resource): boolean;
    protected _bufferPlay(resource: Resource): Promise<void>;
    protected _shouldUpdateInfo(resource: Resource): boolean;
    protected _updateInfo(resource: Resource): Promise<void>;
    protected get _shouldManageSwarm(): boolean;
    protected _manageSwarm(): Promise<void>;
    protected _fetchResource(resource: Resource): Promise<void>;
    abort(resource: Resource): Promise<void>;
    protected _abortResource(resource: Resource): Promise<void>;
    close(): Promise<void>;
    protected _deleteSource(): Promise<void>;
}
type HLSControllerOptions = HLSControllerInfoOptions;
declare class HLSControllerInfo {
    protected _episode: HLSArchive;
    protected _details: Map<string, HLSControllerInfoDetail>;
    constructor(options: HLSControllerInfoOptions);
    get episode(): HLSArchive;
    get details(): Map<string, HLSControllerInfoDetail>;
    isManaged(resource: Resource): boolean;
    isPlaylist(resource: Resource): boolean;
    isSwarmed(resource: Resource): boolean;
    isEpisode(resource: Resource): boolean;
    isManifest(resource: Resource): boolean;
    isSegment(resource: Resource): boolean;
    findDetail(name: string): Nullable<HLSControllerInfoDetail>;
}
type HLSControllerInfoOptions = {
    episode: HLSArchive;
};
declare class HLSControllerInfoDetail {
    protected _manifests: Map<string, HLSManifest>;
    protected _lastManifest?: Nullable<HLSManifest>;
    protected _lastSegment?: Nullable<Resource>;
    protected _playManifest?: Nullable<HLSManifest>;
    protected _playSegment?: Nullable<Resource>;
    protected _playSegments: Map<string, Resource>;
    protected _playStableTime: Timer;
    get manifests(): Map<string, HLSManifest>;
    set manifests(values: Map<string, HLSManifest>);
    get lastManifest(): Nullable<HLSManifest>;
    set lastManifest(value: Nullable<HLSManifest>);
    get lastSegment(): Nullable<Resource>;
    set lastSegment(value: Nullable<Resource>);
    get playManifest(): Nullable<HLSManifest>;
    set playManifest(value: Nullable<HLSManifest>);
    get playSegment(): Nullable<Resource>;
    set playSegment(value: Nullable<Resource>);
    get playSegments(): Map<string, Resource>;
    set playSegments(values: Map<string, Resource>);
    get playStableTime(): Timer;
    isSwarmed(resource: Resource): boolean;
    isManifest(resource: Resource): boolean;
    isSegment(resource: Resource): boolean;
}
declare class HLSArchive {
    protected _id: string;
    protected _uri: string;
    constructor(options: HLSArchiveOptions);
    get id(): string;
    set id(value: string);
    get uri(): string;
    set uri(value: string);
}
type HLSArchiveOptions = {
    id: string;
    uri: string;
};
declare class HLSManifest extends HLSArchive {
    protected _segments: Map<string, HLSSegment>;
    constructor(options: HLSManifestOptions);
    get segments(): Map<string, HLSSegment>;
    set segments(value: Map<string, HLSSegment>);
    isSegment(resource: Resource): boolean;
}
type HLSManifestOptions = HLSArchiveOptions & {
    segments: Map<string, HLSSegment>;
};
declare class HLSSegment extends HLSArchive {
    protected _duration: number;
    protected _hasParts: boolean;
    constructor(options: HLSSegmentOptions);
    get duration(): number;
    set duration(value: number);
    get hasParts(): boolean;
    set hasParts(value: boolean);
}
type HLSSegmentOptions = HLSArchiveOptions & {
    duration: number;
    hasParts: boolean;
};
export { HLSProxy, HLSLoaderProxy };
