import { Nullable } from '@mlytics/core-ts/core/type/basic';
declare const kernelSettings: KernelSettings;
type KernelSettings = {
    global: GlobalSettings;
    logger: LoggerSettings;
    webrtc: WebRTCSettings;
    client: ClientSettings;
    server: ServerSettings;
    system: SystemSettings;
    stream: StreamSettings;
    swproxy: SWProxySettings;
    monitor: MonitorSettings;
    download: DownloadSettings;
    software: SoftwareSettings;
};
type GlobalSettings = {
    mode: string;
    accountID: string;
    streamID: string;
    streamType: string;
    clientID: string;
    clientKey: string;
    muxEnvKey: string;
    platform: Nullable<PlatformSettings>;
    assets: Record<string, AssetSettings>;
};
type PlatformSettings = {
    details: PlatformDetail[];
};
type PlatformDetail = {
    id: string;
    providerID: string;
    type: string;
    name: string;
    host: string;
    score: number;
    isEnabled: boolean;
};
type AssetSettings = {
    id: string;
    tags: string[];
};
type LoggerSettings = {
    level: string;
};
type WebRTCSettings = {
    options: RTCConfiguration;
};
type ClientSettings = {
    id: Nullable<string>;
    key: Nullable<string>;
    token: Nullable<string>;
    origin: Nullable<string>;
    peerID: Nullable<string>;
    accountID: Nullable<string>;
    sessionID: Nullable<string>;
};
type ServerSettings = {
    host: {
        fqdn: string;
        version: string;
    };
    token: {
        fqdn: Nullable<string>;
        version: string;
    };
    metering: {
        fqdn: Nullable<string>;
        version: string;
    };
    tracker: {
        fqdns: Nullable<string[]>;
        version: string;
    };
};
type SystemSettings = {
    mode: Nullable<string>;
    isP2PAllowed: boolean;
};
type StreamSettings = {
    streamID: Nullable<string>;
    streamType: Nullable<string>;
    maxBufferSize: number;
    minBufferTime: number;
    maxBufferTime: number;
};
type SWProxySettings = {
    scriptPath: Nullable<string>;
    scriptScope: Nullable<string>;
};
type MonitorSettings = {
    muxEnvKey: Nullable<string>;
    gtagTargetID: Nullable<string>;
    sampleRate: number;
    isEnabled: boolean;
};
type DownloadSettings = {
    maxCacheItems: number;
    maxP2PPossibility: number;
    httpResponseTimeout: number;
};
type SoftwareSettings = {
    version: string;
    gitTag: string;
    gitCommit: string;
};
export { kernelSettings, KernelSettings, GlobalSettings, PlatformSettings, PlatformDetail };
