import { Nullable, ObjectLike } from '@mlytics/core-ts/core/type/basic';
import { TimeSeriesDataLike } from '../../../model/service/metrics';
import { HTTPDownloadRecord, P2PDownloadRecord } from './record';
import { HTTPDownloadAggregationReport, P2PDownloadAggregationReport } from './report';
type DomainMetrics = {
    id?: string;
    kind: string;
    type: string;
    download: {
        count: {
            usage: {
                dataset: TimeSeriesData<number>[];
                pulse: {
                    dataset: TimeSeriesData<number>[];
                };
                cumulation: {
                    dataset: TimeSeriesData<number>[];
                };
            };
            success: {
                dataset: TimeSeriesData<number>[];
                pulse: {
                    dataset: TimeSeriesData<number>[];
                };
                cumulation: {
                    dataset: TimeSeriesData<number>[];
                };
            };
            failure: {
                dataset: TimeSeriesData<number>[];
                pulse: {
                    dataset: TimeSeriesData<number>[];
                };
                cumulation: {
                    dataset: TimeSeriesData<number>[];
                };
            };
        };
        outcome: {
            dataset: TimeSeriesData<number>[];
        };
        traffic: {
            dataset: TimeSeriesData<number>[];
            pulse: {
                dataset: TimeSeriesData<number>[];
            };
            cumulation: {
                dataset: TimeSeriesData<number>[];
            };
        };
        bandwidth: {
            dataset: TimeSeriesData<number>[];
            wma: {
                dataset: TimeSeriesData<number>[];
            };
        };
    };
};
type CDNMetrics = DomainMetrics & {
    id: string;
    name: string;
    domain: string;
    isEnabled: boolean;
    download: {
        meanBandwidth: {
            dataset: TimeSeriesData<number>[];
            last: {
                dataset: TimeSeriesData<number>[];
            };
        };
        meanAvailability: {
            dataset: TimeSeriesData<number>[];
            last: {
                dataset: TimeSeriesData<number>[];
            };
        };
        currentScore: {
            dataset: TimeSeriesData<number>[];
            last: {
                dataset: TimeSeriesData<number>[];
            };
        };
    };
};
type OriginMetrics = DomainMetrics;
type PeerMetrics = {
    download: {
        count: {
            usage: {
                dataset: TimeSeriesData<number>[];
                pulse: {
                    dataset: TimeSeriesData<number>[];
                };
                cumulation: {
                    dataset: TimeSeriesData<number>[];
                };
            };
        };
        traffic: {
            dataset: TimeSeriesData<number>[];
            pulse: {
                dataset: TimeSeriesData<number>[];
            };
            cumulation: {
                dataset: TimeSeriesData<number>[];
            };
        };
        bandwidth: {
            dataset: TimeSeriesData<number>[];
            wma: {
                dataset: TimeSeriesData<number>[];
            };
        };
    };
};
type TrackerMetrics = {
    peerID: Nullable<string>;
    isAvailable: boolean;
};
type NodeMetrics = {
    peerID: Nullable<string>;
    isAvailable: boolean;
};
type SwarmMetrics = {
    swarmID: string;
    swarmURI: string;
    isAvailable: boolean;
    users: ObjectLike<UserMetrics>;
};
type UserMetrics = PeerMetrics & {
    peerID: string;
    isAvailable: boolean;
};
type SourceMetrics = {
    http: {
        download: {
            records: HTTPDownloadRecord[];
        };
    };
    p2p: {
        download: {
            records: P2PDownloadRecord[];
        };
    };
};
type ReportMetrics = {
    http: {
        download: {
            aggregation: {
                reports: HTTPDownloadAggregationReport[];
            };
        };
    };
    p2p: {
        download: {
            aggregation: {
                reports: P2PDownloadAggregationReport[];
            };
        };
    };
};
type TimeSeriesData<Value = unknown> = TimeSeriesDataLike & {
    value: Value;
};
export { DomainMetrics, CDNMetrics, OriginMetrics, PeerMetrics, TrackerMetrics, NodeMetrics, SwarmMetrics, UserMetrics, SourceMetrics, ReportMetrics, TimeSeriesData };
