import { Nullable } from '@mlytics/core-ts/core/type/basic';
import { SpecQueue } from '@mlytics/core-ts/core/util/queue';
import { Payload } from '@mlytics/core-ts/utility/requester';
import { Resource } from '../../../model/service/resource';
import { CDNSource } from '../../../servant/mcdn/model/mcdn';
import { AbstractDownloader } from './base/loader';
declare class BaseDownloaderProxyName {
    static readonly HTTP = "http";
}
declare abstract class AbstractDownloaderAgent {
    makeProxyClasses(): DownloaderProxyConstructor[];
    protected abstract get _proxyNames(): string[];
    protected abstract get _proxyClasses(): Map<string, DownloaderProxyConstructor>;
}
declare abstract class AbstractDownloaderProxy extends AbstractDownloader {
    fetch(): Promise<void>;
    protected abstract _setup(): Promise<void>;
    protected _beforeFetch(): Promise<void>;
    protected _afterFetch(): Promise<void>;
}
interface DownloaderProxyConstructor {
    new (resource: Resource): AbstractDownloaderProxy;
}
declare abstract class AbstractHttpDownloaderProxy extends AbstractDownloaderProxy {
    protected readonly _resource: Resource;
    protected _aborter: import("abort-controller").default;
    protected _payload: Payload;
    protected _requestURI: string;
    protected constructor(_resource: Resource);
    protected _fetching(): Promise<void>;
    protected get _responseStatus(): number;
    protected _buildAborter(): Promise<void>;
    protected _buildPayload(): Promise<void>;
    protected _handleEntireContent(): Promise<void>;
    protected _handlePartialContent(): Promise<void>;
    protected _handleInvalidContent(): Promise<void>;
    protected _concatResourceChunk(isPartial: boolean): Promise<void>;
    protected _updateResourceType(): Promise<void>;
    protected _updateResourceTotal(): Promise<void>;
    protected _abort(): Promise<void>;
}
declare class MCDNDownloaderProxy extends AbstractHttpDownloaderProxy {
    protected readonly _resource: Resource;
    protected _error?: Nullable<Error>;
    protected _source: CDNSource;
    protected _sources: SpecQueue<CDNSource>;
    protected _startSize: number;
    protected _startTime: number;
    protected _measurement: PerformanceResourceTiming;
    constructor(_resource: Resource);
    protected _setup(): Promise<void>;
    protected _resetStates(): Promise<void>;
    protected _checkStates(): Promise<void>;
    protected get _isWithinStartDelay(): boolean;
    protected _ensureSources(): Promise<void>;
    protected _fetchSource(): Promise<void>;
    protected _buildRequestURI(): Promise<void>;
    protected _fetching(): Promise<void>;
    protected get _shouldRetry(): boolean;
    protected _buildMeasurement(): Promise<void>;
    protected _recordDownload(): Promise<void>;
    protected _clearPerformance(): Promise<void>;
}
export { BaseDownloaderProxyName, AbstractDownloaderAgent, AbstractDownloaderProxy, DownloaderProxyConstructor, AbstractHttpDownloaderProxy, MCDNDownloaderProxy };
