import { Nullable } from '@mlytics/core-ts/core/type/basic';
import { CommonDuty, CommonTaskOptions, SpecTask, TaskManager } from '@mlytics/core-ts/core/util/future';
import { Resource } from '../../../model/service/resource';
import { Request } from '../model/request';
import { ResourceCache } from '../model/resource';
import { AbstractFileDownloader } from './loader';
declare abstract class AbstractFileSeeker {
    protected _requester: AbstractFileRequester;
    protected _resourceCache: ResourceCache;
    protected abstract _initialize(): void;
    activate(): Promise<void>;
    protected abstract _activate(): Promise<void>;
    deactivate(): Promise<void>;
    protected abstract _deactivate(): Promise<void>;
    fetch(resource: Resource): Promise<Resource>;
    prefetch(resource: Resource): Promise<Resource>;
    protected _fetch(resource: Resource, isBlocking: boolean): Promise<Resource>;
    protected _request(resource: Resource, isBlocking: boolean): Promise<void>;
    cache(resource: Resource): Promise<Resource>;
    protected _cache(resource: Resource): Promise<Resource>;
    abort(resource: Resource): Promise<void>;
    protected _hasCached(resource: Resource): boolean;
    protected _fetchCache(resource: Resource): Nullable<Resource>;
    protected _storeCache(resource: Resource): void;
}
declare abstract class AbstractFileRequester {
    static readonly ABORTED_REQUEST_EXPIRY_TIME: number;
    protected _taskManager: TaskManager;
    protected _requestPool: Map<string, Request>;
    activate(): Promise<void>;
    protected abstract _activate(): Promise<void>;
    deactivate(): Promise<void>;
    protected abstract _deactivate(): Promise<void>;
    protected abstract _buildTasks(): Promise<void>;
    fetch(resource: Resource): Promise<Request>;
    abort(resource: Resource): Promise<void>;
    clear(resource: Resource): Promise<void>;
    protected _abortRequest(request: Request): Promise<void>;
    protected _buildRequest(resource: Resource): Promise<Request>;
    protected _fetchRequest(resource: Resource): Nullable<Request>;
    protected _storeRequest(resource: Resource, request: Request): void;
    protected _clearRequest(resource: Resource): void;
    protected abstract _buildObtainResourceTask(resource: Resource): Promise<SpecTask>;
    protected _buildClearRequestTask(): Promise<void>;
    protected _execClearRequestTaskCallee(): Promise<void>;
}
declare class FileRequesterTaskName {
    static readonly CLEAR_REQUEST = "file requester: clear request";
    static readonly OBTAIN_RESOURCE = "file requester: obtain resource";
}
declare abstract class AbstractObtainResourceDuty extends CommonDuty<Resource> {
    protected readonly _options: ObtainResourceDutyOptions;
    protected _downloader: AbstractFileDownloader;
    protected constructor(_options: ObtainResourceDutyOptions);
    protected abstract _initialize(): void;
    callee(): Promise<void>;
    onFail(): Promise<void>;
    onCancel(): Promise<void>;
}
type ObtainResourceDutyOptions = CommonTaskOptions<Resource>;
export { AbstractFileSeeker, AbstractFileRequester, FileRequesterTaskName, AbstractObtainResourceDuty, ObtainResourceDutyOptions };
