import Emittery from 'emittery';
import { BufferLike, Nullable } from '@mlytics/core-ts/core/type/basic';
import { Channel, ChannelHub, Condition } from '@mlytics/core-ts/core/util/future';
import { RTCPeerConnection } from '@mlytics/core-ts/native/webrtc';
import { AbstractBrokerInfo, SpecBroker } from '../../base/broker/broker';
interface SpecPeerBroker extends SpecBroker, SpecConstraintPeerBroker {
    info: PeerBrokerInfo;
    createOffer(): Promise<RTCSessionDescriptionInit>;
    createAnswer(): Promise<RTCSessionDescriptionInit>;
    commitOffer(offer: RTCSessionDescriptionInit): Promise<void>;
    commitAnswer(answer: RTCSessionDescriptionInit): Promise<void>;
    addIceCandidate(ice: RTCIceCandidateInit): Promise<void>;
}
interface SpecConstraintPeerBroker {
    info: PeerBrokerInfo;
    isAvailable: boolean;
}
declare class PeerBroker implements SpecPeerBroker {
    protected _info: PeerBrokerInfo;
    protected _client: PeerClient;
    protected _condition: Condition<unknown>;
    protected _eventHub: ChannelHub;
    protected _messageHub: ChannelHub;
    protected _deliverChannel: Channel<BufferLike>;
    protected _receiveChannel: Channel<unknown>;
    constructor();
    get info(): PeerBrokerInfo;
    get condition(): Condition;
    get eventHub(): ChannelHub;
    get messageHub(): ChannelHub;
    get deliverChannel(): Channel<BufferLike>;
    get receiveChannel(): Channel;
    get isActivated(): boolean;
    get isConnected(): boolean;
    get isSendable(): boolean;
    get isAvailable(): boolean;
    activate(): Promise<void>;
    deactivate(): Promise<void>;
    sendMessage(data: BufferLike): Promise<void>;
    commitMessage(data: BufferLike): Promise<void>;
    createOffer(): Promise<RTCSessionDescriptionInit>;
    createAnswer(): Promise<RTCSessionDescriptionInit>;
    commitOffer(offer: RTCSessionDescriptionInit): Promise<void>;
    commitAnswer(answer: RTCSessionDescriptionInit): Promise<void>;
    addIceCandidate(ice: RTCIceCandidateInit): Promise<void>;
    protected _bindEvents(): Promise<void>;
    protected _openEventHub(): Promise<void>;
}
declare class PeerBrokerInfo extends AbstractBrokerInfo {
    protected _swarmID?: Nullable<string>;
    protected _resourceStats: Map<string, number>;
    get id(): Nullable<string>;
    get swarmID(): Nullable<string>;
    set swarmID(value: Nullable<string>);
    get resourceStats(): Map<string, number>;
    set resourceStats(values: Map<string, number>);
}
declare class PeerBrokerID {
    static make(peerID: string, swarmID?: Nullable<string>): string;
}
declare class PeerClient extends Emittery {
    protected readonly _options?: RTCConfiguration | undefined;
    static readonly DEFAULT_DATACHANNEL_NAME = "datachannel";
    protected _state: PeerState;
    protected _connection: RTCPeerConnection;
    protected _dataChannel?: RTCDataChannel;
    constructor(_options?: RTCConfiguration | undefined);
    get state(): SpecPeerState;
    get bufferedAmount(): number;
    send(data: BufferLike): Promise<void>;
    close(): Promise<void>;
    createOffer(): Promise<RTCSessionDescriptionInit>;
    createAnswer(): Promise<RTCSessionDescriptionInit>;
    commitOffer(offer: RTCSessionDescriptionInit): Promise<void>;
    commitAnswer(answer: RTCSessionDescriptionInit): Promise<void>;
    addIceCandidate(ice: RTCIceCandidateInit): Promise<void>;
    protected _bindConnection(): void;
    protected _bindDataChannel(): void;
    protected _buildDataChannel(): Promise<void>;
    protected _onNegotiationNeeded(): Promise<void>;
    protected _onIceCandidate(event: RTCPeerConnectionIceEvent): Promise<void>;
    protected _onSignalingStateChange(): Promise<void>;
    protected _onIceGatheringStateChange(): Promise<void>;
    protected _onIceConnectionStateChange(): Promise<void>;
    protected _onDataChannel(event: RTCDataChannelEvent): Promise<void>;
    protected _onDataChannelOpen(): Promise<void>;
    protected _onDataChannelData(event: MessageEvent): Promise<void>;
    protected _onDataChannelError(): Promise<void>;
    protected _onDataChannelClose(): Promise<void>;
}
declare class WebRTCEvent {
    static readonly ICE_NEGOTIATION = "ice_negotiation";
    static readonly ICE_CANDIDATE = "ice_candidate";
    static readonly ICE_SIGNALING = "ice_signaling";
    static readonly ICE_GATHERING = "ice_gathering";
    static readonly ICE_CONNECTION = "ice_connection";
    static readonly DATACHANNEL_OPEN = "datachannel_open";
    static readonly DATACHANNEL_DATA = "datachannel_data";
    static readonly DATACHANNEL_ERROR = "datachannel_error";
    static readonly DATACHANNEL_CLOSE = "datachannel_close";
}
declare class PeerEvent extends WebRTCEvent {
    static readonly CONNECTION_CLOSED = "connection_closed";
}
interface SpecPeerState {
    isInitial: boolean;
    isConnected: boolean;
    isDestroyed: boolean;
}
declare class PeerState implements SpecPeerState {
    protected _name: PeerStateName;
    constructor();
    get isInitial(): boolean;
    get isConnected(): boolean;
    get isDestroyed(): boolean;
    toInitial(): void;
    toConnected(): void;
    toDestroyed(): void;
}
declare class PeerStateName {
    static readonly INITIAL = "initial";
    static readonly CONNECTED = "connected";
    static readonly DESTROYED = "destroyed";
}
export { SpecPeerBroker, SpecConstraintPeerBroker, PeerBroker, PeerBrokerInfo, PeerBrokerID, PeerEvent };
