import { Channel, ChannelHub } from '@mlytics/core-ts/core/util/future';
import { AbstractDaemon, SpecDaemon } from '../../../base/daemon/daemon';
import { AbstractProcessAgent } from '../../../base/daemon/process/flow/agent';
import { AbstractProcessPipe, ProcessPipeContent, ProcessPipeOutcome } from '../../../base/daemon/process/flow/pipe';
import { PeerBroker, SpecConstraintPeerBroker } from '../../broker/broker';
interface SpecPeerDaemon extends SpecDaemon {
    broker: SpecConstraintPeerBroker;
    command<Pipe extends AbstractProcessPipe>(command: PeerDaemonCommandOptions<Pipe>): Promise<ProcessPipeOutcome<Pipe>>;
}
declare abstract class AbstractPeerDaemon extends AbstractDaemon implements SpecPeerDaemon {
    protected _agent: AbstractProcessAgent;
    protected _broker: PeerBroker;
    protected _commands: Channel<PeerDaemonCommandOptions<unknown>>;
    protected _submissions: ChannelHub;
    get broker(): PeerBroker;
    command<Pipe extends AbstractProcessPipe>(command: PeerDaemonCommandOptions<Pipe>): Promise<ProcessPipeOutcome<Pipe>>;
    protected _buildWaitToStartTask(): Promise<void>;
    protected _execWaitToStartTaskCallee(): Promise<void>;
    protected abstract _buildConnectPeerTask(): Promise<void>;
    protected _buildListenIceNegotiationEventTask(): Promise<void>;
    protected _execListenIceNegotiationEventTaskCallee(): Promise<void>;
    protected _buildListenIceCandidateEventTask(): Promise<void>;
    protected _execListenIceCandidateEventTaskCallee(): Promise<void>;
    protected _buildListenIceSignalingEventTask(): Promise<void>;
    protected _execListenIceSignalingEventTaskCallee(): Promise<void>;
    protected _buildListenIceGatheringEventTask(): Promise<void>;
    protected _execListenIceGatheringEventTaskCallee(): Promise<void>;
    protected _buildListenIceConnectionEventTask(): Promise<void>;
    protected _execListenIceConnectionEventTaskCallee(): Promise<void>;
    protected _buildListenDataChannelOpenEventTask(): Promise<void>;
    protected _execListenDataChannelOpenEventTaskCallee(): Promise<void>;
    protected _buildListenDataChannelDataEventTask(): Promise<void>;
    protected _execListenDataChannelDataEventTaskCallee(): Promise<void>;
    protected _buildListenDataChannelErrorEventTask(): Promise<void>;
    protected _execListenDataChannelErrorEventTaskCallee(): Promise<void>;
    protected _buildListenDataChannelCloseEventTask(): Promise<void>;
    protected _execListenDataChannelCloseEventTaskCallee(): Promise<void>;
    protected _buildListenConnectionClosedEventTask(): Promise<void>;
    protected _execListenConnectionClosedEventTaskCallee(): Promise<void>;
    protected _buildDeliverMessageTask(): Promise<void>;
    protected _execDeliverMessageTaskCallee(): Promise<void>;
    protected _buildReceiveMessageTask(): Promise<void>;
    protected _execReceiveMessageTaskCallee(): Promise<void>;
    protected _buildProcessMessageTask(): Promise<void>;
    protected _execProcessMessageTaskCallee(): Promise<void>;
    protected _buildProcessCommandTask(): Promise<void>;
    protected _execProcessCommandTaskCallee(): Promise<void>;
    protected _buildExitProcessTask(): Promise<void>;
    protected _execExitProcessTaskOnClose(): Promise<void>;
}
declare class PeerDaemonEvent {
    static readonly CONNECTED = "connected";
    static readonly DISCONNECTED = "disconnected";
}
declare class PeerDaemonTaskName {
    static readonly WAIT_TO_START = "peer daemon: wait to start";
    static readonly CONNECT_PEER = "peer daemon: connect peer";
    static readonly LISTEN_ICE_NEGOTIATION_EVENT = "peer daemon: listen ice negotiation event";
    static readonly LISTEN_ICE_CANDIDATE_EVENT = "peer daemon: listen ice candidate event";
    static readonly LISTEN_ICE_SIGNALING_EVENT = "peer daemon: listen ice signaling event";
    static readonly LISTEN_ICE_GATHERING_EVENT = "peer daemon: listen ice gathering event";
    static readonly LISTEN_ICE_CONNECTION_EVENT = "peer daemon: listen ice connection event";
    static readonly LISTEN_DATACHANNEL_OPEN_EVENT = "peer daemon: listen datachannel open event";
    static readonly LISTEN_DATACHANNEL_DATA_EVENT = "peer daemon: listen datachannel data event";
    static readonly LISTEN_DATACHANNEL_ERROR_EVENT = "peer daemon: listen datachannel error event";
    static readonly LISTEN_DATACHANNEL_CLOSE_EVENT = "peer daemon: listen datachannel close event";
    static readonly LISTEN_CONNECTION_CLOSED_EVENT = "peer daemon: listen connection closed event";
    static readonly DELIVER_MESSAGE = "peer daemon: deliver message";
    static readonly RECEIVE_MESSAGE = "peer daemon: receive message";
    static readonly PROCESS_MESSAGE = "peer daemon: process message";
    static readonly PROCESS_COMMAND = "peer daemon: process command";
    static readonly EXIT_PROCESS = "peer daemon: exit process";
}
type PeerDaemonCommandOptions<Pipe> = {
    id: string;
    name: string;
    content?: ProcessPipeContent<Pipe>;
};
export { SpecPeerDaemon, AbstractPeerDaemon, PeerDaemonEvent, PeerDaemonTaskName, PeerDaemonCommandOptions };
