import { Nullable } from '@mlytics/core-ts/core/type/basic';
import { Channel, ChannelHub } from '@mlytics/core-ts/core/util/future';
import { AbstractDaemon, SpecDaemon } from '../../../base/daemon/daemon';
import { SwarmInfo, SwarmUser } from '../../base/swarm';
import { AbstractProcessAgent } from './process/base/agent';
import { AbstractProcessPipe, ProcessPipeContent, ProcessPipeOutcome } from './process/base/pipe';
interface SpecSwarmDaemon extends SpecDaemon {
    info: SwarmInfo;
    command<Pipe extends AbstractProcessPipe>(command: SwarmDaemonCommandOptions<Pipe>): Promise<ProcessPipeOutcome<Pipe>>;
}
declare abstract class AbstractSwarmDaemon extends AbstractDaemon implements SpecSwarmDaemon {
    protected readonly _options: SwarmDaemonOptions;
    protected _info: SwarmInfo;
    protected _agent: AbstractProcessAgent;
    protected _commands: Channel<SwarmDaemonCommandOptions<unknown>>;
    protected _submissions: ChannelHub;
    constructor(_options: SwarmDaemonOptions);
    get info(): SwarmInfo;
    command<Pipe extends AbstractProcessPipe>(command: SwarmDaemonCommandOptions<Pipe>): Promise<ProcessPipeOutcome<Pipe>>;
    protected _buildWaitToStartTask(): Promise<void>;
    protected _execWaitToStartTaskCallee(): Promise<void>;
    protected _buildJoinSwarmTask(): Promise<void>;
    protected _execJoinSwarmTaskCallee(): Promise<void>;
    protected _execJoinSwarmTaskOnFinish(): Promise<void>;
    protected _buildReportSwarmStatsTask(): Promise<void>;
    protected _execReportSwarmStatsCallee(): Promise<void>;
    protected _buildObtainSwarmUsersTask(): Promise<void>;
    protected _execObtainSwarmUsersCallee(): Promise<void>;
    protected get _shouldObtainSwarmUsers(): boolean;
    protected _buildConnectSwarmUsersTask(): Promise<void>;
    protected _execConnectSwarmUsersCallee(): Promise<void>;
    protected get _shouldConnectSwarmUser(): boolean;
    protected get _nextCandidateSwarmUser(): Nullable<SwarmUser>;
    protected _buildReportResourceStatsTask(): Promise<void>;
    protected _execReportResourceStatsCallee(): Promise<void>;
    protected get _shouldReportResourceStats(): boolean;
    protected _buildProcessCommandTask(): Promise<void>;
    protected _execProcessCommandTaskCallee(): Promise<void>;
    protected _buildExitProcessTask(): Promise<void>;
    protected _execExitProcessTaskOnClose(): Promise<void>;
}
type SwarmDaemonOptions = {
    info: SwarmInfo;
};
declare class SwarmDaemonEvent {
    static readonly CONNECTED = "connected";
    static readonly DISCONNECTED = "disconnected";
}
declare class SwarmDaemonTaskName {
    static readonly WAIT_TO_START = "swarm daemon: wait to start";
    static readonly JOIN_SWARM = "swarm daemon: join swarm";
    static readonly REPORT_SWARM_STATS = "swarm daemon: report swarm stats";
    static readonly OBTAIN_SWARM_USERS = "swarm daemon: obtain swarm users";
    static readonly CONNECT_SWARM_USERS = "swarm daemon: connect swarm users";
    static readonly REPORT_RESOURCE_STATS = "swarm daemon: report resource stats";
    static readonly PROCESS_COMMAND = "swarm daemon: process command";
    static readonly EXIT_PROCESS = "swarm daemon: exit process";
}
type SwarmDaemonCommandOptions<Pipe> = {
    id: string;
    name: string;
    content?: ProcessPipeContent<Pipe>;
};
export { SpecSwarmDaemon, AbstractSwarmDaemon, SwarmDaemonOptions, SwarmDaemonEvent, SwarmDaemonTaskName };
